#!/bin/sh
set +u  # Allows unset variables just in this subshell

# Supports environmental variables:
#   NORUN:  Do not actually execute the JVM (for testing purposes)
#   VERBOSE:  Obviously...
# These variables must be exported from the caller's environment, or invoke
# like:  VERBOSE=true NORUN=true .../path/to/d20Pro.sh [args...]

# This file must be located in the main d20Pro installation directory.

# Default values
XMX=1g


case "$0" in
/*) SCRIPTDIR="${0%/*}";; */*) SCRIPTDIR="$PWD/${0%/*}";; *) SCRIPTDIR="$PWD";;
esac
case "$SCRIPTDIR" in *?/.) SCRIPTDIR="${SCRIPTDIR%/.}"; esac

cd "$SCRIPTDIR"
[ -f "$SCRIPTDIR/invocation.settings" ] &&
[ -r "$SCRIPTDIR/invocation.settings" ] && . "$SCRIPTDIR/invocation.settings"

[ $# -gt 0 ] && unset APP_ARGS

[ -n "$VERBOSE" ] && {
    [ -f "$SCRIPTDIR/invocation.settings" ] &&
    [ -r "$SCRIPTDIR/invocation.settings" ] &&
    echo "Loading '$SCRIPTDIR/invocation.settings'" 1>&2
    echargs java -Xmx$XMX -Dsun.java2d.ddoffscreen=false -Dsun.java2d.noddraw -Dsun.java2d.d3d=false -jar D20PRO.jar "$@" "${APP_ARGS[@]}" 1>&2
}

[ -n "$NORUN" ] && exit 0

exec java -Xmx$XMX -Dsun.java2d.ddoffscreen=false -Dsun.java2d.noddraw -Dsun.java2d.d3d=false -jar D20PRO.jar "$@" "${APP_ARGS}" &
